/* start.c */

/* Direttive */
#include <stdlib.h>
#include <stdio.h>
#include <string.h>

#define ROW_LENGTH 256

typedef int boolean;
#define TRUE  1
#define FALSE 0


/* Prototipi delle procedure secondarie */
void InterpretaLineaComando (int argc, char *argv[], char *filedati);

void GestisceCatalogo (char *nomedati);

boolean GestisceArticolo (FILE *fp);


/* Programma principale */
int main (int argc, char *argv[])
{
  /* Parte dichiarativa */
  char nomedati[ROW_LENGTH];


  /* Parte esecutiva */

  /* Acquisisce dalla linea di comando il nome del file contenente il catalogo */
  InterpretaLineaComando(argc,argv,nomedati);

  /* Apre il file e converte il catalogo */
  GestisceCatalogo(nomedati);

  return EXIT_SUCCESS;
}


/* Definizione delle procedure secondarie */

void InterpretaLineaComando (int argc, char *argv[], char *filedati)
{
  if (argc != 2)
  {
    fprintf(stderr,"Errore nella linea di comando!\n");
    exit(EXIT_FAILURE);
  }

  strcpy(filedati,argv[1]);
}


boolean GestisceArticolo (FILE *fp)
{
  char riga[ROW_LENGTH];
  char articolo[10+1];
  float prezzo;
  int giorno;
  char mese[9+1];
  int anno;
  int n;
  int m;


  /* Acquisisce un articolo da file */
  fgets(riga,ROW_LENGTH,fp);

  n = sscanf(riga,"%s %f %d %s %d",articolo,&prezzo,&giorno,mese,&anno);
  if ( (n == 1) && (strcmp(articolo,"STOP") == 0) ) return FALSE;
  if (n != 5)
  {
    fprintf(stderr,"Errore nei dati!\n");
    exit(EXIT_FAILURE);
  }

  /* Verifica la correttezza dei dati (se ne possono eseguire altre) */
  if ( (giorno <= 0) || (giorno > 31) )
  {
    fprintf(stderr,"Errore nei dati!\n");
    exit(EXIT_FAILURE);
  }

  /* Converte il mese da stringa a numero */
  if (strcmp(mese,"gennaio") == 0)
    m = 1;
  else if (strcmp(mese,"febbraio") == 0)
    m = 2;
  else if (strcmp(mese,"marzo") == 0)
    m = 3;
  else if (strcmp(mese,"aprile") == 0)
    m = 4;
  else if (strcmp(mese,"maggio") == 0)
    m = 5;
  else if (strcmp(mese,"giugno") == 0)
    m = 6;
  else if (strcmp(mese,"luglio") == 0)
    m = 7;
  else if (strcmp(mese,"agosto") == 0)
    m = 8;
  else if (strcmp(mese,"settembre") == 0)
    m = 9;
  else if (strcmp(mese,"ottobre") == 0)
    m = 10;
  else if (strcmp(mese,"novembre") == 0)
    m = 11;
  else if (strcmp(mese,"dicembre") == 0)
    m = 12;
  else
  {
    fprintf(stderr,"Errore nei dati!\n");
    exit(EXIT_FAILURE);
  }

  /* Stampa l'articolo nel formato richiesto */
  sprintf(riga,"%-10s%9.2f %02d/%02d/%04d",articolo,prezzo,giorno,m,anno);
  puts(riga);

  return TRUE;
}


void GestisceCatalogo (char *nomedati)
{
  /* Parte dichiarativa */
  FILE* fp_filedati;
  boolean risultato;


  /* Parte esecutiva */
  fp_filedati = fopen(nomedati,"r");
  if (fp_filedati == NULL)
  {
    fprintf(stderr,"Apertura del file %s fallita!\n",nomedati);
    exit(EXIT_FAILURE);
  }

  do {
    risultato = GestisceArticolo(fp_filedati);
  } while (risultato == TRUE);

  fclose(fp_filedati);
}
